@@ -36,18 +36,38 @@ public:
   virtual std::string GetPlayingGame() const = 0;
 
   /*!
-   * \brief Creates a Savestate
+   * \brief Creates a savestate
    *
    * \param autosave Whether the save type is auto
+   *
+   * \return The path to the created savestate, or empty on error
    */
   virtual std::string CreateSavestate(bool autosave) = 0;
 
+  /*!
+   * \brief Updates a savestate with the current game being played
+   *
+   * \param savestatePath The path to the savestate
+   *
+   * \return True if the savestate was updated, false on error
+   */
+  virtual bool UpdateSavestate(const std::string& savestatePath) = 0;
+
   /*!
    * \brief Loads a savestate
    *
-   * \param path The path to the savestate
+   * \param savestatePath The path to the savestate
+   *
+   * \return True if the savestate was loaded, false on error
    */
-  virtual bool LoadSavestate(const std::string& path) = 0;
+  virtual bool LoadSavestate(const std::string& savestatePath) = 0;
+
+  /*!
+   * \brief Frees resources allocated to the savestate, such as its video thumbnail
+   *
+   * \param savestatePath The path to the savestate
+   */
+  virtual void FreeSavestateResources(const std::string& savestatePath) = 0;
 
   /*!
    * \brief Closes the OSD
